/**
 * 公共接口模块
 */

import {get,post} from './index'

/**
 * 上传错误日志
 */
export function apiReportingErrInfo(params){
    let obj={
        ...params,
        timestamp:new Date().toLocaleString(),
        agent:'ETA移动端',
        page:window.location.href,
        token:localStorage.getItem('token')
    }
    return post('/resource/public/wechat_warning',{content:JSON.stringify(obj)})
}

/**
 * 获取oss临时签名
 * @param {*} params.StorageSource number 1：oss 2：minio
 */
export function apiGetOSSSign(params){
    return get('/resource/oss/get_sts_token',params)
}

/**
 * 获取报告微信小程序太阳码
 * @param CodeScene 页面所需参数
 * @param CodePage eg:pages-report/chapterDetail 小程序中的页面路径
 */
export function apiGetWXQRCodeImg(params){
    return post('/report/getSunCode',params)
}

/**
 * 设置系统配置项
 * @param ConfigCode edb指标库语言edb_language；预测指标库语言predict_edb_language
 *                   ETA图库语言chart_language
 * @param ConfigValue 中文CN 英文EN
 */
export function apiCommonSetSysConfig(params){
    return post('/system/sysuser/config/set',params)
}

/**
 * 获取系统中模块语言设置
 * @param SourceKey edb指标库语言edb_language；预测指标库语言predict_edb_language；ETA图库语言chart_language
 */
export function apiGetLanguageConfig(params){
    return get('/system/config/language',params)
}

/**
 * 获取系统按钮权限
 */
export function apiGetAuthBtnList(){
    return get('/system/role/menu/buttons',{})
}

/**
 * 获取系统动态配置配置
 */
export function apiGetPublicSetting(){
    return get('/system/config',{})
}

/**
 * 校验研报分类是否有审批流
 * @param {Object} params 
 * @param {Number} params.ReportType 报告类型：1-中文研报；2-英文研报；3-智能研报
 * @param {Number} params.ClassifyFirstId 倒数第二级分类的id
 * @param {Number} params.ClassifySecondId 倒数第一级分类的id
 * @returns 
 */
export function apiCheckClassify(params){
    return post('/report_approve/classify/check_open',params)
}

/**
 * 获取用户信息
 */
export function getSystemInfo(){
    return get('/system/sysuser/detail')
}

/**
 * 获取复制链接
 * @param {*} params 
 * @returns 
 */
export function shareGenerate(params){
    return post('/report/share/generate',params)
}

/**
 * 上传图片
 * @param {*} params 
 * @returns 
 */
export function uploadImgAPi(params) {
    return post('/banner/upload',params)
}