/**
 * 中文/英文ppt模块
 */

import {get,post} from './index'

/**
 * ppt分类数据
 */
export function apiPPTClassify(){
    if(window.location.pathname.startsWith('/ppten')){
        return get('/ppt_english/groups',{})
    }else{
        return get('/pptv2/groups',{})
    }
}

/**
 * 复制ppt目录
 * @param GroupId 目录id
 */
export function apiPPTCatalogueCopy(params){
    if(window.location.pathname.startsWith('/ppten')){
        return post('/ppt_english/group/copy',params)
    }else{
        return post('/pptv2/group/copy',params)
    }
}

/**
 * 删除ppt目录
 * @param GroupId 目录id
 */
export function apiPPTCatalogueDel(params){
    if(window.location.pathname.startsWith('/ppten')){
        return post('/ppt_english/group/delete',params)
    }else{
        return post('/pptv2/group/delete',params)
    }
    
}

/**
 * ppt目录重命名
 * @param GroupId 目录id
 * @param GroupName:目录名称
 */
export function apiPPTCatalogueRename(params){
    if(window.location.pathname.startsWith('/ppten')){
        return post('/ppt_english/group/rename',params)
    }else{
        return post('/pptv2/group/rename',params)
    }
    
}


/**
 * 删除ppt
 * @param PptId pptid
 */
export function apiPPTDel(params){
    if(window.location.pathname.startsWith('/ppten')){
        return post('/ppt_english/delete',params)
    }else{
        return post('/pptv2/delete',params)
    }
}

/**
 * 共享/取消共享ppt
 * @param PptId
 */
export function apiPPTShare(params){
    if(window.location.pathname.startsWith('/ppten')){
        return post('/ppt_english/share',params)
    }else{
        return post('/pptv2/share',params)
    }
    
}

/**
 * 复制ppt到目录
 * @param PptId 
 * @param GroupId
 */
export function apiPPTCopy(params){
    if(window.location.pathname.startsWith('/ppten')){
        return post('/ppt_english/copy',params)
    }else{
        return post('/pptv2/copy',params)
    }
}

/**
 * 获取ppt详情
 * @param PptId
 */
export function apiPPTDetail(params){
    if(window.location.pathname.startsWith('/ppten')){
        return get('/ppt_english/detail',params)
    }else{
        return get('/pptv2/detail',params)
    }
}

/**
 * 发布ppt
 * @param PptId
 * @param PptxUrl
 */
export function apiPPTPublish(params){
    if(window.location.pathname.startsWith('/ppten')){
        return post('/ppt_english/publish',params)
    }else{
        return post('/pptv2/publish',params)
    }
}

/**
 * 我的ppt列表
 * @param GroupId 分类id
 */
export function apiPPTList(params) {
    if(window.location.pathname.startsWith('/ppten')){
        return get('/ppt_english/group/ppt/list',params)
    }else{
        return get('/pptv2/group/ppt/list',params)
    }
}

/**
 * 公共ppt列表
 * @param AdminId
 */
export function apiPPTPubList(params){
    if(window.location.pathname.startsWith('/ppten')){
        return get('/ppt_english/share/ppt/list',params)
    }else{
        return get('/pptv2/share/ppt/list',params)
    }
}

/**
 * ppt搜索
 * @param Keyword
 */
export function apiPPTSearch(params){
    if(window.location.pathname.startsWith('/ppten')){
        return get('/ppt_english/ppt/list',params)
    }else{
        return get('/pptv2/ppt/list',params)
    }
}

/**
     * 共享ppt列表
     * @param {*} params GroupId
     */
export function apiPPTShareList(params){
    if(window.location.pathname.startsWith('/ppten')){
        return get('/ppt_english/grant/ppt/list',params)
    }else{
        return get('/pptv2/grant/ppt/list',params)
    }
}


/**
     * 取消共享
     * @param {*} params  PptId
     * @returns 
*/
export function cancelShareAuth(params) {
    if(window.location.pathname.startsWith('/ppten')){
        return post('/ppt_english/grant/cancel',params)
    }else{
        return post('/pptv2/grant/cancel',params)
    }
}


/**
     * 设置共享
     * @param 
     * * PptId 
	 * GrantType  1：全部用户；2：指定成员
	 * AdminIdStr
*/
export function setShareAuth(params) {
    if(window.location.pathname.startsWith('/ppten')){
        return post('/ppt_english/grant',params)
    }else{
        return post('/pptv2/grant',params)
    }
}

/**
     * 获取分配ppt详情
     * @param {*} params PptId
     * @returns 
     */
export function getSharedDetail(params) {
    if(window.location.pathname.startsWith('/ppten')){
        return get('/ppt_english/grant/info',params)
    }else{
        return get('/pptv2/grant/info',params)
    }
}

/**
	 * 用户检索
	 * @param {KeyWord} params 
	 * @returns 
	 */
export function userSearch(params) {
    return get('/datamanage/manual/sysuser/search',params)
}